module BittrexEnterprise
  class Addresses
    include ApiHelpers

  # ==============================================================================================
  # AUTH REQUIRED ================================================================================
  # ==============================================================================================

    # -------------------------------------- LIST ------------------------------------------------
    # List deposit addresses that have been requested or provisioned.
    #
    # ------ PARAMS ------
    # sub_account_id: string - optional - ID of the subaccount to use for this call
    # --------------------------------------------------------------------------------------------
    def self.list(sub_account_id=nil)
      get_signed 'addresses', sub_account_id: sub_account_id
    end


    # -------------------------------------- CREATE ----------------------------------------------
    # Request provisioning of a deposit address for a currency for which no address has been
    # requested or provisioned.
    #
    # ------ PARAMS ------
    # currency_symbol - string - required - the currency ID to provision a new address for
    #
    # sub_account_id: string - optional - ID of the subaccount to use for this call
    # --------------------------------------------------------------------------------------------
    def self.create(currency_symbol, sub_account_id=nil)
      post_signed 'addresses', currencySymbol: currency_symbol, sub_account_id: sub_account_id
    end


    # -------------------------------------- STATUS ----------------------------------------------
    # Retrieve the status of the deposit address for a particular currency for which one has
    # been requested or provisioned.
    # ------ PARAMS ------
    # currency_symbol - string - required - symbol of the currency to retrieve the deposit
    #                                       address for
    # sub_account_id: string - optional - ID of the subaccount to use for this call
    # --------------------------------------------------------------------------------------------
    def self.status(currency_symbol, sub_account_id=nil)
      get_signed 'addresses/{currencySymbol}', currencySymbol: currency_symbol, sub_account_id: sub_account_id
    end

  end
end
