module BittrexEnterprise
  class Balances
    include ApiHelpers

  # ==============================================================================================
  # AUTH REQUIRED ================================================================================
  # ==============================================================================================

    # ---------------------------------------- LIST ----------------------------------------------
    # List account balances across available currencies. Returns a Balance entry for each
    # currency for which there is either a balance or an address.
    #
    # ------ PARAMS ------
    # sub_account_id: string - optional - ID of the subaccount to use for this call
    # --------------------------------------------------------------------------------------------
    def self.list(sub_account_id='')
      get_signed 'balances', sub_account_id: sub_account_id
    end


    # --------------------------------------- INFO -----------------------------------------------
    # Retrieve account balance for a specific currency. Request will always succeed when the
    # currency exists, regardless of whether there is a balance or address.
    #
    # ------ PARAMS ------
    # currency_symbol: string - required - unique symbol of the currency to retrieve the
    #                                      account balance for
    # sub_account_id: string - optional - ID of the subaccount to use for this call
    # --------------------------------------------------------------------------------------------
    def self.info(currency_symbol, sub_account_id='')
      get_signed 'balances/{currencySymbol}', currencySymbol: currency_symbol, sub_account_id: sub_account_id
    end

  end
end
