module BittrexEnterprise
  class Markets
    include ApiHelpers

  # ==============================================================================================
  # PUBLIC METHODS - NO AUTH REQUIRED ============================================================
  # ==============================================================================================

    # ------------------------------------- LIST -------------------------------------------------
    # List markets
    # --------------------------------------------------------------------------------------------
    def self.list
      get 'markets'
    end


    # ----------------------------------- SUMMARIES ----------------------------------------------
    # List summaries of the last 24 hours of activity for all markets.
    # --------------------------------------------------------------------------------------------
    def self.summaries
      get 'markets/summaries'
    end


    # ------------------------------------ INFO --------------------------------------------------
    # Retrieve information for a specific market.
    # ------ PARAMS ------
    # market_symbol: string - required - symbol of market to retrieve
    # --------------------------------------------------------------------------------------------
    def self.info(market_symbol)
      get 'markets/{marketSymbol}', marketSymbol: market_symbol
    end


    # ----------------------------------- SUMMARY ------------------------------------------------
    # Retrieve summary of the last 24 hours of activity for a specific market.
    # ------ PARAMS ------
    # market_symbol: string - required - symbol of market to retrieve summary for
    # --------------------------------------------------------------------------------------------
    def self.summary(market_symbol)
      get 'markets/{marketSymbol}/summary', marketSymbol: market_symbol
    end


    # ---------------------------------- ORDER BOOK ----------------------------------------------
    # Retrieve the order book for a specific market.
    # ------ PARAMS ------
    # market_symbol: string - required - symbol of market to retrieve order book for
    # depth: integer - optional - maximum depth of order book to return
    #                             (allowed values are [1, 25, 500], default is 25)
    # --------------------------------------------------------------------------------------------
    def self.order_book(market_symbol, depth=nil)
      get 'markets/{marketSymbol}/orderbook', marketSymbol: market_symbol, depth: depth
    end


    # ------------------------------------ TRADES ------------------------------------------------
    # Retrieve the recent trades for a specific market.
    # ------ PARAMS ------
    # market_symbol: string - required - symbol of market to retrieve recent trades for
    # --------------------------------------------------------------------------------------------
    def self.trades(market_symbol)
      get 'markets/{marketSymbol}/trades', marketSymbol: market_symbol
    end


    # ----------------------------------- TICKER -------------------------------------------------
    # Retrieve the ticker for a specific market.
    # ------ PARAMS ------
    # market_symbol: string - required - symbol of market to retrieve recent trades for
    # --------------------------------------------------------------------------------------------
    def self.ticker(market_symbol)
      get 'markets/{marketSymbol}/trades', marketSymbol: market_symbol
    end
    

    # ----------------------------------- CANDLES ------------------------------------------------
    # Retrieve recent candles for a specific market. The maximum age of the returned candles
    # depends on the interval as follows:
    # (MINUTE_1: 1 day, MINUTE_5: 1 day, HOUR_1: 31 days, DAY_1: 366 days).
    # Candles for intervals without any trading activity are omitted.
    # ------ PARAMS ------
    # market_symbol: string - required - symbol of market to retrieve recent trades for
    # candle_interval: string_enum - required - desired time interval between candles -
    #                                           [MINUTE_1, MINUTE_5, HOUR_1, DAY_1]
    # --------------------------------------------------------------------------------------------
    def self.candles(market_symbol, candle_interval)
      get 'markets/{marketSymbol}/trades', marketSymbol: market_symbol, candleInterval: candle_interval
    end

  end
end
