module BittrexEnterprise
  class SubAccounts
    include ApiHelpers

  # ==============================================================================================
  # AUTH REQUIRED ================================================================================
  # ==============================================================================================

    # ------------------------------------------ LIST --------------------------------------------
    # List subaccounts. (NOTE: This API is limited to partners and not available for traders.)
    # Pagination and the sort order of the results are in inverse order of the CreatedAt field.
    #
    # ------ PARAMS ------ PARAMS MUST BE PASSED AS KEY VALUE PAIRS
    # nextPageToken - string - The unique identifier of the item that the resulting query result
    #         should start after, in the sort order of the given endpoint. Used for traversing
    #         a paginated set in the forward direction. (May only be specified if PreviousPageToken
    #         is not specified.)
    #
    # previousPageToken - string - The unique identifier of the item that the resulting query
    #         result should end before, in the sort order of the given endpoint. Used for traversing
    #         a paginated set in the reverse direction. (May only be specified if NextPageToken is
    #         not specified.)
    #
    # pageSize - integer - maximum number of items to retrieve -- default 100, minimum 1, maximum 200
    # --------------------------------------------------------------------------------------------
    def self.list(params={})
      get_signed 'subaccounts', params
    end


    # ------------------------------------------ CREATE ------------------------------------------
    # Create a new subaccount. (NOTE: This API is limited to partners and not available for traders.)
    #
    # ------ PARAMS ------
    # no params required. Passes an empty hash
    # --------------------------------------------------------------------------------------------
    def self.create()
      post_signed 'subaccounts', {}
    end


    # --------------------------------------- RETRIEVE -------------------------------------------
    # Retrieve details for a specified subaccount. (NOTE: This API is limited to partners
    # and not available for traders.)
    #
    # ------ PARAMS ------
    # sub_account_id - string - required - (guid-formatted string) - ID of the subaccount to
    #                                                                retrieve details for
    # --------------------------------------------------------------------------------------------
    def self.retrieve(sub_account_id)
      get_signed 'subaccounts/{subaccountId}', subaccountId: sub_account_id
    end

  end
end
