module BittrexEnterprise
  class Transfers
    include ApiHelpers

  # ==============================================================================================
  # AUTH REQUIRED ================================================================================
  # ==============================================================================================

    # ----------------------------------------- SENT ---------------------------------------------
    # List sent transfers. (NOTE: This API is limited to partners and not available for traders.)
    # Pagination and the sort order of the results are in inverse order of the Executed field.
    #
    # ------ PARAMS ------ PARAMS MUST BE PASSED AS KEY VALUE PAIRS
    # toSubaccountId - string - optional
    #
    # toMasterAccount - boolean - optional
    #
    # currencySymbol - string - optional
    #
    # nextPageToken - string - The unique identifier of the item that the resulting query result
    #         should start after, in the sort order of the given endpoint. Used for traversing
    #         a paginated set in the forward direction. (May only be specified if PreviousPageToken
    #         is not specified.)
    #
    # previousPageToken - string - The unique identifier of the item that the resulting query
    #         result should end before, in the sort order of the given endpoint. Used for traversing
    #         a paginated set in the reverse direction. (May only be specified if NextPageToken is
    #         not specified.)
    #
    # pageSize - integer - maximum number of items to retrieve -- default 100, minimum 1, maximum 200
    #
    # startDate - string(date-time) - Filters out results before this timestamp. In ISO 8601 format
    #         (e.g., "2019-01-02T16:23:45Z"). Precision beyond one second is not supported. Use
    #         pagination parameters for more precise filtering.
    #
    # endDate - string(date-time) - Filters out result after this timestamp. Uses the same format
    #         as StartDate. Either, both, or neither of StartDate and EndDate can be set. The only
    #         constraint on the pair is that, if both are set, then EndDate cannot be before StartDate.
    # --------------------------------------------------------------------------------------------
    def self.sent(params={})
      get_signed 'transfers/sent', params
    end


    # -------------------------------------- RECEIVED --------------------------------------------
    # List sent transfers. (NOTE: This API is limited to partners and not available for traders.)
    # Pagination and the sort order of the results are in inverse order of the Executed field.
    #
    # ------ PARAMS ------ PARAMS MUST BE PASSED AS KEY VALUE PAIRS
    # fromSubaccountId - string - optional
    #
    # fromMasterAccount - boolean - optional
    #
    # currencySymbol - string - optional
    #
    # nextPageToken - string - The unique identifier of the item that the resulting query result
    #         should start after, in the sort order of the given endpoint. Used for traversing
    #         a paginated set in the forward direction. (May only be specified if PreviousPageToken
    #         is not specified.)
    #
    # previousPageToken - string - The unique identifier of the item that the resulting query
    #         result should end before, in the sort order of the given endpoint. Used for traversing
    #         a paginated set in the reverse direction. (May only be specified if NextPageToken is
    #         not specified.)
    #
    # pageSize - integer - maximum number of items to retrieve -- default 100, minimum 1, maximum 200
    #
    # startDate - string(date-time) - Filters out results before this timestamp. In ISO 8601 format
    #         (e.g., "2019-01-02T16:23:45Z"). Precision beyond one second is not supported. Use
    #         pagination parameters for more precise filtering.
    #
    # endDate - string(date-time) - Filters out result after this timestamp. Uses the same format
    #         as StartDate. Either, both, or neither of StartDate and EndDate can be set. The only
    #         constraint on the pair is that, if both are set, then EndDate cannot be before StartDate.
    # --------------------------------------------------------------------------------------------
    def self.received(params={})
      get_signed 'transfers/received', params
    end


    # --------------------------------------- RETRIEVE -------------------------------------------
    # Retrieve information on the specified transfer. (NOTE: This API is limited to partners and
    # not available for traders.)
    #
    # ------ PARAMS ------
    # transfer_id - string - required - (guid-formatted string) - ID of the transfer to retrieve
    # --------------------------------------------------------------------------------------------
    def self.retrieve(transfer_id)
      get_signed 'transfers/{transferId}', transferId: transfer_id
    end

    # ---------------------------------------- CREATE --------------------------------------------
    # Executes a new transfer. (NOTE: This API is limited to partners and not available for traders.)
    #
    # ------ PARAMS ------
    # NewTransfer - object - required - information specifying the transfer to execute
    #         {
    #           "toSubaccountId": "string (uuid)",
    #           "requestId": "string (uuid)",
    #           "currencySymbol": "string",
    #           "amount": "number (double)",
    #           "toMasterAccount": "boolean"
    #         }
    #   *** REQUIRED - currencySymbol, amount ***
    # --------------------------------------------------------------------------------------------
    def self.create(new_transfer)
      post_signed 'transfers', new_transfer
    end

  end
end
